@@ -1,20 +1,6 @@
 /*
-*  Copyright 2019  Michail Vourlakos <mvourlakos@gmail.com>
-*
-*  This file is part of Latte-Dock
-*
-*  Latte-Dock is free software; you can redistribute it and/or
-*  modify it under the terms of the GNU General Public License as
-*  published by the Free Software Foundation; either version 2 of
-*  the License, or (at your option) any later version.
-*
-*  Latte-Dock is distributed in the hope that it will be useful,
-*  but WITHOUT ANY WARRANTY; without even the implied warranty of
-*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-*  GNU General Public License for more details.
-*
-*  You should have received a copy of the GNU General Public License
-*  along with this program.  If not, see <http://www.gnu.org/licenses/>.
+    SPDX-FileCopyrightText: 2019 Michail Vourlakos <mvourlakos@gmail.com>
+    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "factory.h"
@@ -31,6 +17,7 @@
 #include <QProcess>
 #include <QTemporaryDir>
 #include <QTimer>
+#include <QLatin1String>
 
 // KDE
 #include <KDirWatch>
@@ -250,7 +237,7 @@ bool Factory::isCustomType(const QString &id) const
 bool Factory::metadataAreValid(KPluginMetaData &metadata)
 {
     return metadata.isValid()
-            && metadata.category() == "Latte Indicator"
+            && metadata.category() == QLatin1String("Latte Indicator")
             && !metadata.value("X-Latte-MainScript").isEmpty();
 }
 
