@@ -1,28 +1,18 @@
 /*
-*  Copyright 2019  Michail Vourlakos <mvourlakos@gmail.com>
-*
-*  This file is part of Latte-Dock
-*
-*  Latte-Dock is free software; you can redistribute it and/or
-*  modify it under the terms of the GNU General Public License as
-*  published by the Free Software Foundation; either version 2 of
-*  the License, or (at your option) any later version.
-*
-*  Latte-Dock is distributed in the hope that it will be useful,
-*  but WITHOUT ANY WARRANTY; without even the implied warranty of
-*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-*  GNU General Public License for more details.
-*
-*  You should have received a copy of the GNU General Public License
-*  along with this program.  If not, see <http://www.gnu.org/licenses/>.
+    SPDX-FileCopyrightText: 2019 Michail Vourlakos <mvourlakos@gmail.com>
+    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "abstractlayout.h"
 
+// local
+#include "../data/layoutdata.h"
+
 // Qt
 #include <QDir>
 #include <QDebug>
 #include <QFile>
+#include <QLatin1String>
 
 // KDE
 #include <KSharedConfig>
@@ -72,6 +62,7 @@ void AbstractLayout::init()
     connect(this, &AbstractLayout::launchersChanged, this, &AbstractLayout::saveConfig);
     connect(this, &AbstractLayout::preferredForShortcutsTouchedChanged, this, &AbstractLayout::saveConfig);
     connect(this, &AbstractLayout::popUpMarginChanged, this, &AbstractLayout::saveConfig);
+    connect(this, &AbstractLayout::schemeFileChanged, this, &AbstractLayout::saveConfig);
     connect(this, &AbstractLayout::versionChanged, this, &AbstractLayout::saveConfig);
 }
 
@@ -131,6 +122,21 @@ QString AbstractLayout::background() const
     }
 }
 
+QString AbstractLayout::schemeFile() const
+{
+    return m_schemeFile;
+}
+
+void AbstractLayout::setSchemeFile(const QString &file)
+{
+    if (m_schemeFile == file) {
+        return;
+    }
+
+    m_schemeFile = file;
+    emit schemeFileChanged();
+}
+
 QString AbstractLayout::textColor() const
 {
     if (m_backgroundStyle == ColorBackgroundStyle) {
@@ -265,27 +271,27 @@ QString AbstractLayout::defaultCustomBackground()
 QString AbstractLayout::defaultTextColor(const QString &color)
 {
     //! the user is in default layout theme
-    if (color == "blue") {
+    if (color == QLatin1String("blue")) {
         return "#D7E3FF";
-    } else if (color == "brown") {
+    } else if (color == QLatin1String("brown")) {
         return "#F1DECB";
-    } else if (color == "darkgrey") {
+    } else if (color == QLatin1String("darkgrey")) {
         return "#ECECEC";
-    } else if (color == "gold") {
+    } else if (color == QLatin1String("gold")) {
         return "#7C3636";
-    } else if (color == "green") {
+    } else if (color == QLatin1String("green")) {
         return "#4D7549";
-    } else if (color == "lightskyblue") {
+    } else if (color == QLatin1String("lightskyblue")) {
         return "#0C2A43";
-    } else if (color == "orange") {
+    } else if (color == QLatin1String("orange")) {
         return "#6F3902";
-    } else if (color == "pink") {
+    } else if (color == QLatin1String("pink")) {
         return "#743C46";
-    } else if (color == "purple") {
+    } else if (color == QLatin1String("purple")) {
         return "#ECD9FF";
-    }  else if (color == "red") {
+    }  else if (color == QLatin1String("red")) {
         return "#F3E4E4";
-    }  else if (color == "wheat") {
+    }  else if (color == QLatin1String("wheat")) {
         return "#6A4E25";
     }  else {
         return "#FCFCFC";
@@ -376,6 +382,15 @@ void AbstractLayout::loadConfig()
     m_color = m_layoutGroup.readEntry("color", QString("blue"));
     m_backgroundStyle = static_cast<BackgroundStyle>(m_layoutGroup.readEntry("backgroundStyle", (int)ColorBackgroundStyle));
 
+    m_schemeFile = m_layoutGroup.readEntry("schemeFile", QString(Data::Layout::DEFAULTSCHEMEFILE));
+
+    if (m_schemeFile.startsWith("~")) {
+        m_schemeFile.remove(0, 1);
+        m_schemeFile = QDir::homePath() + m_schemeFile;
+    }
+
+    m_schemeFile = m_schemeFile.isEmpty() || !QFileInfo(m_schemeFile).exists() ? Data::Layout::DEFAULTSCHEMEFILE : m_schemeFile;
+
     QString deprecatedTextColor = m_layoutGroup.readEntry("textColor", QString());
     QString deprecatedBackground = m_layoutGroup.readEntry("background", QString());
 
@@ -409,6 +424,15 @@ void AbstractLayout::saveConfig()
     m_layoutGroup.writeEntry("lastUsedActivity", m_lastUsedActivity);
     m_layoutGroup.writeEntry("popUpMargin", m_popUpMargin);
     m_layoutGroup.writeEntry("preferredForShortcutsTouched", m_preferredForShortcutsTouched);
+
+    QString scmfile = m_schemeFile;
+
+    if (scmfile.startsWith(QDir::homePath())) {
+        scmfile.remove(0, QDir::homePath().size());
+        scmfile = "~" + scmfile;
+    }
+    m_layoutGroup.writeEntry("schemeFile", scmfile == Data::Layout::DEFAULTSCHEMEFILE ? "" : scmfile);
+
     m_layoutGroup.sync();
 }
 
