@@ -1,20 +1,6 @@
 /*
-*  Copyright 2019  Michail Vourlakos <mvourlakos@gmail.com>
-*
-*  This file is part of Latte-Dock
-*
-*  Latte-Dock is free software; you can redistribute it and/or
-*  modify it under the terms of the GNU General Public License as
-*  published by the Free Software Foundation; either version 2 of
-*  the License, or (at your option) any later version.
-*
-*  Latte-Dock is distributed in the hope that it will be useful,
-*  but WITHOUT ANY WARRANTY; without even the implied warranty of
-*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-*  GNU General Public License for more details.
-*
-*  You should have received a copy of the GNU General Public License
-*  along with this program.  If not, see <http://www.gnu.org/licenses/>.
+    SPDX-FileCopyrightText: 2019 Michail Vourlakos <mvourlakos@gmail.com>
+    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #ifndef ABSTRACTLAYOUT_H
@@ -73,6 +59,8 @@ class AbstractLayout : public QObject
     Q_PROPERTY(QString background READ background NOTIFY backgroundChanged)
     Q_PROPERTY(QString textColor READ textColor NOTIFY textColorChanged)
 
+    Q_PROPERTY(QString schemeFile READ schemeFile WRITE setSchemeFile NOTIFY schemeFileChanged)
+
     Q_PROPERTY(QStringList launchers READ launchers WRITE setLaunchers NOTIFY launchersChanged)
     Q_PROPERTY(QString lastUsedActivity READ lastUsedActivity NOTIFY lastUsedActivityChanged)
 
@@ -111,6 +99,9 @@ public:
 
     QString predefinedTextColor() const;
 
+    QString schemeFile() const;
+    void setSchemeFile(const QString &file);
+
     virtual QString textColor() const;
     void setTextColor(QString color);
 
@@ -145,6 +136,7 @@ signals:
     void nameChanged();
     void popUpMarginChanged();
     void preferredForShortcutsTouchedChanged();
+    void schemeFileChanged();
     void textColorChanged();
     void versionChanged();
 
@@ -171,6 +163,7 @@ protected:
     QString m_color;
     QString m_lastUsedActivity; //the last used activity for this layout
     QString m_icon;
+    QString m_schemeFile;
 
     BackgroundStyle m_backgroundStyle{ColorBackgroundStyle};
 
