@@ -513,8 +513,6 @@ void TabLayouts::removeLayout()
         return;
     }
 
-    qDebug() << Q_FUNC_INFO;
-
     m_layoutsController->removeSelected();
 }
 
@@ -714,7 +712,7 @@ void TabLayouts::exportLayoutForBackup()
     });
 
     exportFileDialog->open();
-    exportFileDialog->selectFile(selectedLayout.name);
+    exportFileDialog->selectFile(selectedLayout.name + ".layout.latte");
 }
 
 void TabLayouts::showDetailsDialog()
