@@ -318,6 +318,15 @@ void Effects::setInputMask(QRect area)
     m_inputMask = area;
 
     if (KWindowSystem::isPlatformX11()) {
+        if (m_view->devicePixelRatio() != 1.0) {
+            //!Fix for X11 Global Scale
+            auto ratio = m_view->devicePixelRatio();
+            area = QRect(qRound(area.x() * ratio),
+                         qRound(area.y() * ratio),
+                         qRound(area.width()*ratio),
+                         qRound(area.height() * ratio));
+        }
+
         m_corona->wm()->setInputMask(m_view, area);
     } else {
         //under wayland mask() is providing the Input Area
@@ -577,7 +586,7 @@ void Effects::updateEffects()
                 //! Latte is now using GtkFrameExtents so Effects geometries must be adjusted
                 //! windows that use GtkFrameExtents and apply Effects on them they take GtkFrameExtents
                 //! as granted
-                if (KWindowSystem::isPlatformX11()) {
+                if (KWindowSystem::isPlatformX11() && !m_view->byPassWM()) {
                     if (m_view->location() == Plasma::Types::BottomEdge) {
                         fY = qMax(0, fY - m_view->headThicknessGap());
                     } else if (m_view->location() == Plasma::Types::RightEdge) {
