@@ -190,6 +190,10 @@ View::View(Plasma::Corona *corona, QScreen *targetScreen, bool byPassX11WM)
             emit inEditModeChanged();
         });
 
+        connect(this->containment(), &Plasma::Containment::destroyedChanged, this, [&]() {
+            m_inDelete = containment()->destroyed();
+        });
+
         if (m_corona->viewSettingsFactory()->hasOrphanSettings()
                 && m_corona->viewSettingsFactory()->hasVisibleSettings()
                 && m_corona->viewSettingsFactory()->lastContainment() == containment()) {
@@ -297,6 +301,16 @@ void View::init(Plasma::Containment *plasma_containment)
     connect(this, &View::activitiesChanged, this, &View::applyActivitiesToWindows);
     connect(m_positioner, &ViewPart::Positioner::winIdChanged, this, &View::applyActivitiesToWindows);
 
+    connect(this, &View::alignmentChanged, this, [&](){
+        // inform neighbour vertical docks/panels to adjust their positioning
+        if (m_inDelete || formFactor() == Plasma::Types::Vertical) {
+            return;
+        }
+
+        emit availableScreenRectChangedFrom(this);
+        emit availableScreenRegionChangedFrom(this);
+    });
+
     connect(this, &View::maxLengthChanged, this, [&]() {
         if (m_inDelete) {
             return;
@@ -523,8 +537,6 @@ void View::newView(const QString &templateFile)
 void View::removeView()
 {
     if (m_layout) {
-        m_inDelete = true;
-
         QAction *removeAct = action("remove");
 
         if (removeAct) {
@@ -589,6 +601,14 @@ void View::showConfigurationInterface(Plasma::Applet *applet)
     } else {
         m_appletConfigView = new PlasmaQuick::ConfigView(applet);
         m_appletConfigView.data()->init();
+
+        //! center applet config window
+        m_appletConfigView->setScreen(screen());
+        QRect scrgeometry = screenGeometry();
+        QPoint position{scrgeometry.center().x() - m_appletConfigView->width() / 2, scrgeometry.center().y() - m_appletConfigView->height() / 2 };
+        //!under wayland probably needs another workaround
+        m_appletConfigView->setPosition(position);
+
         m_appletConfigView->show();
     }
 }
